@@ -145,11 +145,14 @@ def read_pkg_file(self, file):
 
 
 def single_line(val):
-    """Validate that the value does not have line breaks."""
-    # Ref: https://github.com/pypa/setuptools/issues/1390
+    """
+    Quick and dirty validation for Summary pypa/setuptools#1390.
+    """
     if '\n' in val:
-        raise ValueError('Newlines are not allowed')
-
+        # TODO: Replace with `raise ValueError("newlines not allowed")`
+        # after reviewing #2893.
+        warnings.warn("newlines not allowed and will break in the future")
+        val = val.strip().split('\n')[0]
     return val
 
 
